@@ -277,6 +277,7 @@ https://creativecommons.org/publicdomain/zero/1.0/ .
 
 from __future__ import print_function
 
+import configparser
 import errno
 import json
 import os
@@ -284,11 +285,6 @@ import re
 import subprocess
 import sys
 
-try:
-    import configparser
-except ImportError:
-    import ConfigParser as configparser
-
 
 class VersioneerConfig:
     """Container for Versioneer configuration parameters."""
